@@ -15,7 +15,14 @@
 // specific language governing permissions and limitations
 // under the License.
 
+/// Default scheme for foundationdb service.
+pub const FOUNDATIONDB_SCHEME: &str = "foundationdb";
+
 mod backend;
+mod config;
+mod core;
+mod deleter;
+mod writer;
 
-pub use backend::FoundationConfig;
 pub use backend::FoundationdbBuilder as Foundationdb;
+pub use config::FoundationdbConfig;
